@@ -8,8 +8,9 @@ context("lrren")
 ## Environmental Covariates
 library(envi)
 library(raster)
-library(spatstat)
 library(spatstat.data)
+library(spatstat.geom)
+library(spatstat.core)
 set.seed(1234)
 
 # -------------- #
@@ -27,24 +28,24 @@ grad_raster <- raster::raster(grad)
 
 ## Presence Locations
 presence <- spatstat.data::bei
-spatstat::marks(presence) <- data.frame("presence" = rep(1, presence$n),
-                                   "lon" = presence$x,
-                                   "lat" = presence$y)
-spatstat::marks(presence)$elev <- elev[presence]
-spatstat::marks(presence)$grad <- grad[presence]
+spatstat.geom::marks(presence) <- data.frame("presence" = rep(1, presence$n),
+                                             "lon" = presence$x,
+                                             "lat" = presence$y)
+spatstat.geom::marks(presence)$elev <- elev[presence]
+spatstat.geom::marks(presence)$grad <- grad[presence]
 
 # (Pseudo-)Absence Locations
 set.seed(1234) # for reproducibility
-absence <- spatstat::rpoispp(0.008, win = elev)
-spatstat::marks(absence) <- data.frame("presence" = rep(0, absence$n),
-                                       "lon" = absence$x,
-                                       "lat" = absence$y)
-spatstat::marks(absence)$elev <- elev[absence]
-spatstat::marks(absence)$grad <- grad[absence]
+absence <- spatstat.core::rpoispp(0.008, win = elev)
+spatstat.geom::marks(absence) <- data.frame("presence" = rep(0, absence$n),
+                                            "lon" = absence$x,
+                                            "lat" = absence$y)
+spatstat.geom::marks(absence)$elev <- elev[absence]
+spatstat.geom::marks(absence)$grad <- grad[absence]
 
 # Combine
-obs_locs <- spatstat::superimpose(presence, absence, check = FALSE)
-obs_locs <- spatstat::marks(obs_locs)
+obs_locs <- spatstat.geom::superimpose(presence, absence, check = FALSE)
+obs_locs <- spatstat.geom::marks(obs_locs)
 obs_locs$id <- seq(1, nrow(obs_locs), 1)
 obs_locs <- obs_locs[ , c(6, 2, 3, 1, 4, 5)]
 
@@ -59,7 +60,7 @@ custom_chull_pts <- rbind(custom_chull_pts, custom_chull_pts[1, ])
 custom_chull_poly <- sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(custom_chull_pts)), 1)))
 #add small buffer around polygon to include boundary points
 custom_poly <- custom_chull_poly@polygons[[1]]@Polygons[[1]]@coords #extract coordinates of new polygon
-custom_owin <- spatstat::owin(poly = list(x = rev(custom_poly[ , 1]),
+custom_owin <- spatstat.geom::owin(poly = list(x = rev(custom_poly[ , 1]),
                                                y = rev(custom_poly[ , 2])))
 
 
@@ -240,6 +241,24 @@ test_that("lrren works", {
           obs_window = custom_owin,
           verbose = FALSE)
   )
+  
+  # Only estimates ecological niche
+  ## p-value correction
+  expect_named(
+    lrren(obs_locs = obs_locs,
+          predict = FALSE,
+          predict_locs = predict_locs,
+          conserve = FALSE,
+          p_correct = "Bonferroni",
+          cv = FALSE,
+          kfold = 10,
+          balance = FALSE,
+          parallel = FALSE,
+          n_core = NULL,
+          poly_buffer = NULL,
+          obs_window = NULL,
+          verbose = FALSE)
+  )
 
   # Estimate and cross-validation
   ## Unbalanced sampling
