@@ -8,8 +8,9 @@ context("perlrren")
 ## Environmental Covariates
 library(envi)
 library(raster)
-library(spatstat)
 library(spatstat.data)
+library(spatstat.geom)
+library(spatstat.core)
 set.seed(1234)
 
 # -------------- #
@@ -25,30 +26,30 @@ ims[[2]]$v <- scale(ims[[2]]$v)
 
 # Presence locations
 presence <- spatstat.data::bei
-spatstat::marks(presence) <- data.frame("presence" = rep(1, presence$n),
+spatstat.geom::marks(presence) <- data.frame("presence" = rep(1, presence$n),
                                              "lon" = presence$x,
                                              "lat" = presence$y)
 
 # (Pseudo-)Absence locations
-absence <- spatstat::rpoispp(0.008, win = ims[[1]])
-spatstat::marks(absence) <- data.frame("presence" = rep(0, absence$n),
+absence <- spatstat.core::rpoispp(0.008, win = ims[[1]])
+spatstat.geom::marks(absence) <- data.frame("presence" = rep(0, absence$n),
                                             "lon" = absence$x,
                                             "lat" = absence$y)
 
 # Combine into readable format
-obs_locs <- spatstat::superimpose(presence, absence, check = FALSE)
-spatstat::marks(obs_locs)$id <- seq(1, obs_locs$n, 1)
-spatstat::marks(obs_locs) <- spatstat::marks(obs_locs)[ , c(4, 2, 3, 1)]
+obs_locs <- spatstat.geom::superimpose(presence, absence, check = FALSE)
+spatstat.geom::marks(obs_locs)$id <- seq(1, obs_locs$n, 1)
+spatstat.geom::marks(obs_locs) <- spatstat.geom::marks(obs_locs)[ , c(4, 2, 3, 1)]
 
 obs_locs1 <- obs_locs
 
 # Specify categories for varying degrees of spatial uncertainty
 ## Creates three groups
-spatstat::marks(obs_locs)$levels <- as.factor(stats::rpois(obs_locs$n, lambda = 0.05))
+spatstat.geom::marks(obs_locs)$levels <- as.factor(stats::rpois(obs_locs$n, lambda = 0.05))
 
 # Incorrect inputs
 obs_locs2 <- obs_locs
-spatstat::marks(obs_locs2)$levels <- NULL
+spatstat.geom::marks(obs_locs2)$levels <- NULL
 
 test_that("perlrren throws error with invalid arguments", {
   
@@ -77,13 +78,13 @@ test_that("perlrren throws error with invalid arguments", {
              n_sim = 10)
   )
   
-  # A radius of 0
-  expect_error(
-    perlrren(obs_ppp = obs_locs,
-             covariates = ims,
-             radii = c(0, 100, 500),
-             n_sim = 10)
-  )
+  # # A radius of 0
+  # expect_error(
+  #   perlrren(obs_ppp = obs_locs,
+  #            covariates = ims,
+  #            radii = c(0, 100, 500),
+  #            n_sim = 10)
+  # )
   
   # Incorrect length of ims
   expect_error(
@@ -151,6 +152,16 @@ test_that("perlrren works", {
              n_sim = 10)
   )
   
+  # p-value correction
+  expect_named(
+    perlrren(obs_ppp = obs_locs,
+             predict = FALSE,
+             p_correct = "Bonferroni",
+             covariates = ims,
+             radii = c(10, 100, 500),
+             n_sim = 10)
+  )
+  
   # Alpha small
   expect_named(
     perlrren(obs_ppp = obs_locs,
